flatten_path

Function flatten_path 

pub fn flatten_path(entry: &Path) -> LingResult<Program>
Resolve use/mod imports for entry and return the flattened AST. Used by the JIT to prime its fallback interpreter with the same program it compiles.