pub fn init_aot_runtime()Expand description
Initialize the AOT/JIT runtime. Must be called before any AOT-compiled code. Creates a new interpreter instance for runtime function dispatch.
pub fn init_aot_runtime()Initialize the AOT/JIT runtime. Must be called before any AOT-compiled code. Creates a new interpreter instance for runtime function dispatch.