pub struct Interpreter {
pub source_dir: Option<PathBuf>,
/* private fields */
}Fields
source_dir: Option<PathBuf>Directory of the primary source file, for relative use resolution.
Implementations
Sourceimpl Interpreter
impl Interpreter
pub fn new() -> Self
Sourcepub fn take_error_trace(&mut self) -> Vec<String>
pub fn take_error_trace(&mut self) -> Vec<String>
Take the call-stack snapshot captured at the deepest runtime error, if any. Frames are ordered outermost-first (entry point first, failing call last).
pub fn run_program(&mut self, program: &Program) -> Result<(), String>