Crate ling

Crate ling 

Re-exports

pub use core::LingCompiler;
pub use core::CompilerConfig;
pub use core::OptimizationLevel;
pub use lexicon::CanonicalToken;
pub use lexicon::Lexicon;
pub use lexicon::LexiconRegistry;
pub use polyglot::normalize_source;
pub use polyglot::ScriptDetector;
pub use ling_audio;

Modules

borrowck
codegen
core
gfx
lexer
lexicon
mir
parser
polyglot
runtime
semantic
utils
visualize

Constants

VERSION

Functions

detect_language
Detect the primary human language used for keywords in a Ling source file.
run
Run a Ling source string through the interpreter. Lexes → parses → executes the start binding.
run_file
Run with an optional source directory for relative use imports.